==> thux.news-2.0.2.tar.gz: thux.news-2.0.2/thux/news/models.py <==
# -*- coding: utf-8 -*-
from __future__ import unicode_literals
from six import python_2_unicode_compatible

import os

from ckeditor.fields import RichTextField
from easy_thumbnails.files import get_thumbnailer
from image_cropping import ImageRatioField

from django.conf import settings
from django.db import models
from django.utils.translation import ugettext_lazy as _

from jmb.core.db.models import DateModel, UserModel, StatusModel, OrderedModel, SEOModel
from thux.i18n.models import Language


def get_upload_small_path(instance, filename):
    media_dir = instance.slug[0:3]
    ext = filename.split('.')[-1]
    filename = '{}.{}'.format(instance.slug, ext)
    return os.path.join('news', 'small', '{0}'.format(media_dir), filename)


def get_upload_big_path(instance, filename):
    media_dir = instance.slug[0:3]
    ext = filename.split('.')[-1]
    filename = '{}.{}'.format(instance.slug, ext)
    return os.path.join('news', 'big', '{0}'.format(media_dir), filename)


def get_upload_file_path(instance, filename):
    media_dir = instance.slug[0:3]
    ext = filename.split('.')[-1]
    filename = '{}.{}'.format(instance.slug, ext)
    return os.path.join('news', 'file', '{0}'.format(media_dir), filename)


@python_2_unicode_compatible
class Category(DateModel, UserModel, StatusModel, OrderedModel):
    name = models.CharField(
        unique=True,
        max_length=255,
        verbose_name=_('name')
    )
    slug = models.SlugField(
        unique=True,
        max_length=255,
        verbose_name=_('slug'),
    )

    class Meta:
        verbose_name = _('category')
        verbose_name_plural = _('categories')
        ordering = ('ordering', 'name')
        permissions = (
            ('list_category', 'Can list category'),
            ('detail_category', 'Can detail category'),
            ('disable_category', 'Can disable category'),
        )

    def __str__(self):
        return self.name


@python_2_unicode_compatible
class News(DateModel, UserModel, StatusModel, OrderedModel, SEOModel):
    categories = models.ManyToManyField(
        Category,
        blank=True,
        related_name='news',
        verbose_name=_('categories')
    )
    title = models.CharField(
        max_length=255,
        unique=True,
        verbose_name=_('default title'),
    )
    slug = models.SlugField(
        max_length=255,
        verbose_name=_('slug'),
        unique=True,
    )
    language = models.ForeignKey(
        Language,
        blank=True, null=True,
        verbose_name=_('language'),
    )
    event_date = models.DateField(
        null=True, blank=True,
        verbose_name=_('news date'),
    )
    pub_date_begin = models.DateTimeField(
        blank=True, null=True,
        verbose_name=_('publication date begin'),
    )
    pub_date_end = models.DateTimeField(
        blank=True, null=True,
        verbose_name=_('publication date end'),
    )
    small_image = models.ImageField(
        upload_to=get_upload_small_path,
        blank=True, null=True,
        verbose_name=_('small Image')
    )
    big_image = models.ImageField(
        upload_to=get_upload_big_path,
        blank=True, null=True,
        verbose_name=_('Big Image')
    )
    small_cropping = ImageRatioField(
        'big_image',
        settings.NEWS_SMALL_CROPPING_SIZE,
        size_warning=True,
        verbose_name=_('small cropping'),
    )
    big_cropping = ImageRatioField(
        'big_image',
        settings.NEWS_BIG_CROPPING_SIZE,
        size_warning=True,
        verbose_name=_('big cropping'),
    )
    short_description = models.CharField(
        max_length=255,
        blank=True, null=True,
        verbose_name=_('short description'),
    )
    full_description = RichTextField(
        blank=True, null=True,
        verbose_name=_('full description'),
    )
    note = models.TextField(
        blank=True, null=True,
        verbose_name=_('note'),
    )
    file = models.FileField(
        upload_to=get_upload_file_path,
        blank=True, null=True,
        verbose_name=_('file'),
    )
    link = models.URLField(
        blank=True, null=True,
        verbose_name=_('link'),
    )

    class Meta:
        verbose_name = _('news')
        verbose_name_plural = _('news')
        ordering = ('ordering', '-event_date', 'title')
        permissions = (
            ('list_news', 'Can list news'),
            ('detail_news', 'Can detail news'),
            ('disable_news', 'Can disable news'),
        )

    def __str__(self):
        return self.title

    def get_small_cropping(self):
        size_list = settings.NEWS_SMALL_CROPPING_SIZE.split('x')
        for i in range(0, len(size_list)):
            size_list[i] = int(size_list[i])
        if self.small_image:
            return get_thumbnailer(
                self.small_image
            ).get_thumbnail({
                'size': tuple(size_list),
                'box': self.small_cropping,
                'crop': True,
                'detail': True,
            }).url
        else:
            return None

    def get_big_cropping(self):
        size_list = settings.NEWS_BIG_CROPPING_SIZE.split('x')
        for i in range(0, len(size_list)):
            size_list[i] = int(size_list[i])
        if self.big_image:
            return get_thumbnailer(
                self.big_image
            ).get_thumbnail({
                'size': tuple(size_list),
                'box': self.big_cropping,
                'crop': True,
                'detail': True,
            }).url
        else:
            return None

    def get_url_file(self):
        if self.file:
            return self.file.url
        return None

==> thux.news-2.0.3.tar.gz: thux.news-2.0.3/thux/news/models.py <==
# -*- coding: utf-8 -*-
from __future__ import unicode_literals
from six import python_2_unicode_compatible

import os

from ckeditor.fields import RichTextField
from easy_thumbnails.files import get_thumbnailer
from image_cropping import ImageRatioField

from django.conf import settings
from django.db import models
from django.utils.translation import ugettext_lazy as _

from jmb.core.db.models import DateModel, UserModel, StatusModel, OrderedModel, SEOModel
from thux.i18n.models import Language


def get_upload_small_path(instance, filename):
    media_dir = instance.slug[0:3]
    ext = filename.split('.')[-1]
    filename = '{}.{}'.format(instance.slug, ext)
    return os.path.join('news', 'small', '{0}'.format(media_dir), filename)


def get_upload_big_path(instance, filename):
    media_dir = instance.slug[0:3]
    ext = filename.split('.')[-1]
    filename = '{}.{}'.format(instance.slug, ext)
    return os.path.join('news', 'big', '{0}'.format(media_dir), filename)


def get_upload_file_path(instance, filename):
    media_dir = instance.slug[0:3]
    ext = filename.split('.')[-1]
    filename = '{}.{}'.format(instance.slug, ext)
    return os.path.join('news', 'file', '{0}'.format(media_dir), filename)


@python_2_unicode_compatible
class Category(DateModel, UserModel, StatusModel, OrderedModel):
    name = models.CharField(
        unique=True,
        max_length=255,
        verbose_name=_('name')
    )
    slug = models.SlugField(
        unique=True,
        max_length=255,
        verbose_name=_('slug'),
    )

    class Meta:
        verbose_name = _('category')
        verbose_name_plural = _('categories')
        ordering = ('ordering', 'name')
        permissions = (
            ('list_category', 'Can list category'),
            ('detail_category', 'Can detail category'),
            ('disable_category', 'Can disable category'),
        )

    def __str__(self):
        return self.name


@python_2_unicode_compatible
class News(DateModel, UserModel, StatusModel, OrderedModel, SEOModel):
    categories = models.ManyToManyField(
        Category,
        blank=True,
        related_name='news',
        verbose_name=_('categories')
    )
    title = models.CharField(
        max_length=255,
        unique=True,
        verbose_name=_('default title'),
    )
    slug = models.SlugField(
        max_length=255,
        verbose_name=_('slug'),
        unique=True,
    )
    language = models.ForeignKey(
        Language,
        blank=True, null=True,
        verbose_name=_('language'),
    )
    event_date = models.DateField(
        null=True, blank=True,
        verbose_name=_('news date'),
    )
    pub_date_begin = models.DateTimeField(
        blank=True, null=True,
        verbose_name=_('publication date begin'),
    )
    pub_date_end = models.DateTimeField(
        blank=True, null=True,
        verbose_name=_('publication date end'),
    )
    small_image = models.ImageField(
        upload_to=get_upload_small_path,
        blank=True, null=True,
        verbose_name=_('small Image')
    )
    big_image = models.ImageField(
        upload_to=get_upload_big_path,
        blank=True, null=True,
        verbose_name=_('Big Image')
    )
    small_cropping = ImageRatioField(
        'small_image',
        settings.NEWS_NEWS_SMALL_CROPPING_SIZE,
        size_warning=True,
        verbose_name=_('small cropping'),
    )
    big_cropping = ImageRatioField(
        'big_image',
        settings.NEWS_NEWS_BIG_CROPPING_SIZE,
        size_warning=True,
        verbose_name=_('big cropping'),
    )
    short_description = models.CharField(
        max_length=255,
        blank=True, null=True,
        verbose_name=_('short description'),
    )
    full_description = RichTextField(
        blank=True, null=True,
        verbose_name=_('full description'),
    )
    note = models.TextField(
        blank=True, null=True,
        verbose_name=_('note'),
    )
    file = models.FileField(
        upload_to=get_upload_file_path,
        blank=True, null=True,
        verbose_name=_('file'),
    )
    link = models.URLField(
        blank=True, null=True,
        verbose_name=_('link'),
    )

    class Meta:
        verbose_name = _('news')
        verbose_name_plural = _('news')
        ordering = ('ordering', '-event_date', 'title')
        permissions = (
            ('list_news', 'Can list news'),
            ('detail_news', 'Can detail news'),
            ('disable_news', 'Can disable news'),
        )

    def __str__(self):
        return self.title

    def get_small_cropping(self):
        size_list = settings.NEWS_NEWS_SMALL_CROPPING_SIZE.split('x')
        for i in range(0, len(size_list)):
            size_list[i] = int(size_list[i])
        if self.small_image:
            return get_thumbnailer(
                self.small_image
            ).get_thumbnail({
                'size': tuple(size_list),
                'box': self.small_cropping,
                'crop': True,
                'detail': True,
            }).url
        else:
            return None

    def get_big_cropping(self):
        size_list = settings.NEWS_NEWS_BIG_CROPPING_SIZE.split('x')
        for i in range(0, len(size_list)):
            size_list[i] = int(size_list[i])
        if self.big_image:
            return get_thumbnailer(
                self.big_image
            ).get_thumbnail({
                'size': tuple(size_list),
                'box': self.big_cropping,
                'crop': True,
                'detail': True,
            }).url
        else:
            return None

    def get_url_file(self):
        if self.file:
            return self.file.url
        return None
